@@ -96,7 +96,7 @@ class InstaClient(Auth, Interactions, Scraper):
     def logger(self) -> Optional[logging.Logger]:
         return LOGGER
 
-    def set_logger_level(self, level:Union[logging.WARNING, logging.DEBUG, logging.INFO]):
+    def set_logger_level(self, level):
         global LOGGER
         LOGGER.setLevel(level)
 
